# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="comment_base.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class CommentBase(object):
    """Comment.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'author': 'str',
        'date_time': 'datetime',
        'initial': 'str',
        'range_end': 'DocumentPosition',
        'range_start': 'DocumentPosition',
        'text': 'str'
    }

    attribute_map = {
        'author': 'Author',
        'date_time': 'DateTime',
        'initial': 'Initial',
        'range_end': 'RangeEnd',
        'range_start': 'RangeStart',
        'text': 'Text'
    }

    def __init__(self, author=None, date_time=None, initial=None, range_end=None, range_start=None, text=None):  # noqa: E501
        """CommentBase - a model defined in Swagger"""  # noqa: E501

        self._author = None
        self._date_time = None
        self._initial = None
        self._range_end = None
        self._range_start = None
        self._text = None
        self.discriminator = None

        if author is not None:
            self.author = author
        if date_time is not None:
            self.date_time = date_time
        if initial is not None:
            self.initial = initial
        if range_end is not None:
            self.range_end = range_end
        if range_start is not None:
            self.range_start = range_start
        if text is not None:
            self.text = text

    @property
    def author(self):
        """Gets the author of this CommentBase.  # noqa: E501

        Gets or sets the author name for a comment.  # noqa: E501

        :return: The author of this CommentBase.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this CommentBase.

        Gets or sets the author name for a comment.  # noqa: E501

        :param author: The author of this CommentBase.  # noqa: E501
        :type: str
        """
        self._author = author

    @property
    def date_time(self):
        """Gets the date_time of this CommentBase.  # noqa: E501

        Gets or sets the date and time that the comment was made.  # noqa: E501

        :return: The date_time of this CommentBase.  # noqa: E501
        :rtype: datetime
        """
        return self._date_time

    @date_time.setter
    def date_time(self, date_time):
        """Sets the date_time of this CommentBase.

        Gets or sets the date and time that the comment was made.  # noqa: E501

        :param date_time: The date_time of this CommentBase.  # noqa: E501
        :type: datetime
        """
        self._date_time = date_time

    @property
    def initial(self):
        """Gets the initial of this CommentBase.  # noqa: E501

        Gets or sets the initials of the user associated with a specific comment.  # noqa: E501

        :return: The initial of this CommentBase.  # noqa: E501
        :rtype: str
        """
        return self._initial

    @initial.setter
    def initial(self, initial):
        """Sets the initial of this CommentBase.

        Gets or sets the initials of the user associated with a specific comment.  # noqa: E501

        :param initial: The initial of this CommentBase.  # noqa: E501
        :type: str
        """
        self._initial = initial

    @property
    def range_end(self):
        """Gets the range_end of this CommentBase.  # noqa: E501

        Gets or sets the link to comment range end node.  # noqa: E501

        :return: The range_end of this CommentBase.  # noqa: E501
        :rtype: DocumentPosition
        """
        return self._range_end

    @range_end.setter
    def range_end(self, range_end):
        """Sets the range_end of this CommentBase.

        Gets or sets the link to comment range end node.  # noqa: E501

        :param range_end: The range_end of this CommentBase.  # noqa: E501
        :type: DocumentPosition
        """
        self._range_end = range_end

    @property
    def range_start(self):
        """Gets the range_start of this CommentBase.  # noqa: E501

        Gets or sets the link to comment range start node.  # noqa: E501

        :return: The range_start of this CommentBase.  # noqa: E501
        :rtype: DocumentPosition
        """
        return self._range_start

    @range_start.setter
    def range_start(self, range_start):
        """Sets the range_start of this CommentBase.

        Gets or sets the link to comment range start node.  # noqa: E501

        :param range_start: The range_start of this CommentBase.  # noqa: E501
        :type: DocumentPosition
        """
        self._range_start = range_start

    @property
    def text(self):
        """Gets the text of this CommentBase.  # noqa: E501

        Gets or sets text of the comment.  # noqa: E501

        :return: The text of this CommentBase.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this CommentBase.

        Gets or sets text of the comment.  # noqa: E501

        :param text: The text of this CommentBase.  # noqa: E501
        :type: str
        """
        self._text = text


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommentBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="replace_text_parameters.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class ReplaceTextParameters(object):
    """Class for document replace text request building.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_match_case': 'bool',
        'is_match_whole_word': 'bool',
        'is_old_value_regex': 'bool',
        'new_value': 'str',
        'old_value': 'str'
    }

    attribute_map = {
        'is_match_case': 'IsMatchCase',
        'is_match_whole_word': 'IsMatchWholeWord',
        'is_old_value_regex': 'IsOldValueRegex',
        'new_value': 'NewValue',
        'old_value': 'OldValue'
    }

    def __init__(self, is_match_case=None, is_match_whole_word=None, is_old_value_regex=None, new_value=None, old_value=None):  # noqa: E501
        """ReplaceTextParameters - a model defined in Swagger"""  # noqa: E501

        self._is_match_case = None
        self._is_match_whole_word = None
        self._is_old_value_regex = None
        self._new_value = None
        self._old_value = None
        self.discriminator = None

        if is_match_case is not None:
            self.is_match_case = is_match_case
        if is_match_whole_word is not None:
            self.is_match_whole_word = is_match_whole_word
        if is_old_value_regex is not None:
            self.is_old_value_regex = is_old_value_regex
        if new_value is not None:
            self.new_value = new_value
        if old_value is not None:
            self.old_value = old_value

    @property
    def is_match_case(self):
        """Gets the is_match_case of this ReplaceTextParameters.  # noqa: E501

        Gets or sets a value indicating whether flag, true means the search is case-sensitive; false means the search is not case-sensitive.  # noqa: E501

        :return: The is_match_case of this ReplaceTextParameters.  # noqa: E501
        :rtype: bool
        """
        return self._is_match_case

    @is_match_case.setter
    def is_match_case(self, is_match_case):
        """Sets the is_match_case of this ReplaceTextParameters.

        Gets or sets a value indicating whether flag, true means the search is case-sensitive; false means the search is not case-sensitive.  # noqa: E501

        :param is_match_case: The is_match_case of this ReplaceTextParameters.  # noqa: E501
        :type: bool
        """
        self._is_match_case = is_match_case

    @property
    def is_match_whole_word(self):
        """Gets the is_match_whole_word of this ReplaceTextParameters.  # noqa: E501

        Gets or sets a value indicating whether flag, means that only whole word matched are replaced.  # noqa: E501

        :return: The is_match_whole_word of this ReplaceTextParameters.  # noqa: E501
        :rtype: bool
        """
        return self._is_match_whole_word

    @is_match_whole_word.setter
    def is_match_whole_word(self, is_match_whole_word):
        """Sets the is_match_whole_word of this ReplaceTextParameters.

        Gets or sets a value indicating whether flag, means that only whole word matched are replaced.  # noqa: E501

        :param is_match_whole_word: The is_match_whole_word of this ReplaceTextParameters.  # noqa: E501
        :type: bool
        """
        self._is_match_whole_word = is_match_whole_word

    @property
    def is_old_value_regex(self):
        """Gets the is_old_value_regex of this ReplaceTextParameters.  # noqa: E501

        Gets or sets a value indicating whether flag, means that OldValue contains regex expression.  # noqa: E501

        :return: The is_old_value_regex of this ReplaceTextParameters.  # noqa: E501
        :rtype: bool
        """
        return self._is_old_value_regex

    @is_old_value_regex.setter
    def is_old_value_regex(self, is_old_value_regex):
        """Sets the is_old_value_regex of this ReplaceTextParameters.

        Gets or sets a value indicating whether flag, means that OldValue contains regex expression.  # noqa: E501

        :param is_old_value_regex: The is_old_value_regex of this ReplaceTextParameters.  # noqa: E501
        :type: bool
        """
        self._is_old_value_regex = is_old_value_regex

    @property
    def new_value(self):
        """Gets the new_value of this ReplaceTextParameters.  # noqa: E501

        Gets or sets the new text value to replace by.  # noqa: E501

        :return: The new_value of this ReplaceTextParameters.  # noqa: E501
        :rtype: str
        """
        return self._new_value

    @new_value.setter
    def new_value(self, new_value):
        """Sets the new_value of this ReplaceTextParameters.

        Gets or sets the new text value to replace by.  # noqa: E501

        :param new_value: The new_value of this ReplaceTextParameters.  # noqa: E501
        :type: str
        """
        self._new_value = new_value

    @property
    def old_value(self):
        """Gets the old_value of this ReplaceTextParameters.  # noqa: E501

        Gets or sets the old text value (or regex pattern IsOldValueRegex) to replace.  # noqa: E501

        :return: The old_value of this ReplaceTextParameters.  # noqa: E501
        :rtype: str
        """
        return self._old_value

    @old_value.setter
    def old_value(self, old_value):
        """Sets the old_value of this ReplaceTextParameters.

        Gets or sets the old text value (or regex pattern IsOldValueRegex) to replace.  # noqa: E501

        :param old_value: The old_value of this ReplaceTextParameters.  # noqa: E501
        :type: str
        """
        self._old_value = old_value


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReplaceTextParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="get_document_hyperlink_by_index_online_request.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import json

from six.moves.urllib.parse import quote
from asposewordscloud import *
from asposewordscloud.models.requests import *
from asposewordscloud.models.responses import *

class GetDocumentHyperlinkByIndexOnlineRequest(BaseRequestObject):
    """
    Request model for get_document_hyperlink_by_index_online operation.
    Initializes a new instance.
    :param document The document.
    :param hyperlink_index The index of the hyperlink.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password for opening an encrypted document.
    """

    def __init__(self, document, hyperlink_index, load_encoding=None, password=None):
        self.document = document
        self.hyperlink_index = hyperlink_index
        self.load_encoding = load_encoding
        self.password = password

    def create_http_request(self, api_client):
        # verify the required parameter 'document' is set
        if self.document is None:
            raise ValueError("Missing the required parameter `document` when calling `get_document_hyperlink_by_index_online`")  # noqa: E501
        # verify the required parameter 'hyperlink_index' is set
        if self.hyperlink_index is None:
            raise ValueError("Missing the required parameter `hyperlink_index` when calling `get_document_hyperlink_by_index_online`")  # noqa: E501

        path = '/v4.0/words/online/get/hyperlinks/{hyperlinkIndex}'
        path_params = {}
        if self.hyperlink_index is not None:
            path_params['hyperlinkIndex'] = self.hyperlink_index  # noqa: E501
        else:
            path_params['hyperlinkIndex'] = ''  # noqa: E501

        # path parameters
        collection_formats = {}
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                path = path.replace(
                    '{%s}' % k,
                    quote(str(v), safe=api_client.configuration.safe_chars_for_path_param)
                )

        # remove optional path parameters
        path = path.replace('//', '/')

        query_params = []
        if self.load_encoding is not None:
                query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
        if self.password is not None:
                query_params.append(('password', self.password))  # noqa: E501

        header_params = {}
        # HTTP header `Content-Type`
        header_params['Content-Type'] = api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        form_params = []
        if self.document is not None:
            form_params.append(['document', self.document, 'file'])  # noqa: E501

        body_params = None
        return {
            "method": "PUT",
            "path": path,
            "query_params": query_params,
            "header_params": header_params,
            "form_params": form_params,
            "body": body_params,
            "collection_formats": collection_formats,
            "response_type": 'HyperlinkResponse'  # noqa: E501
        }

    def get_response_type(self):
        return 'HyperlinkResponse'  # noqa: E501

    def deserialize_response(self, api_client, response):
        return self.deserialize(response, HyperlinkResponse, api_client)



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="move_file_request.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import json

from six.moves.urllib.parse import quote
from asposewordscloud import *
from asposewordscloud.models.requests import *
from asposewordscloud.models.responses import *

class MoveFileRequest(BaseRequestObject):
    """
    Request model for move_file operation.
    Initializes a new instance.
    :param dest_path Destination file path e.g. '/dest.ext'.
    :param src_path Source file's path e.g. '/Folder 1/file.ext' or '/Bucket/Folder 1/file.ext'.
    :param src_storage_name Source storage name.
    :param dest_storage_name Destination storage name.
    :param version_id File version ID to move.
    """

    def __init__(self, dest_path, src_path, src_storage_name=None, dest_storage_name=None, version_id=None):
        self.dest_path = dest_path
        self.src_path = src_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name
        self.version_id = version_id

    def create_http_request(self, api_client):
        # verify the required parameter 'dest_path' is set
        if self.dest_path is None:
            raise ValueError("Missing the required parameter `dest_path` when calling `move_file`")  # noqa: E501
        # verify the required parameter 'src_path' is set
        if self.src_path is None:
            raise ValueError("Missing the required parameter `src_path` when calling `move_file`")  # noqa: E501

        path = '/v4.0/words/storage/file/move/{srcPath}'
        path_params = {}
        if self.src_path is not None:
            path_params['srcPath'] = self.src_path  # noqa: E501
        else:
            path_params['srcPath'] = ''  # noqa: E501

        # path parameters
        collection_formats = {}
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                path = path.replace(
                    '{%s}' % k,
                    quote(str(v), safe=api_client.configuration.safe_chars_for_path_param)
                )

        # remove optional path parameters
        path = path.replace('//', '/')

        query_params = []
        if self.dest_path is not None:
                query_params.append(('destPath', self.dest_path))  # noqa: E501
        if self.src_storage_name is not None:
                query_params.append(('srcStorageName', self.src_storage_name))  # noqa: E501
        if self.dest_storage_name is not None:
                query_params.append(('destStorageName', self.dest_storage_name))  # noqa: E501
        if self.version_id is not None:
                query_params.append(('versionId', self.version_id))  # noqa: E501

        header_params = {}

        form_params = []

        body_params = None
        return {
            "method": "PUT",
            "path": path,
            "query_params": query_params,
            "header_params": header_params,
            "form_params": form_params,
            "body": body_params,
            "collection_formats": collection_formats,
            "response_type": 'None'  # noqa: E501
        }

    def get_response_type(self):
        return 'None'  # noqa: E501

    def deserialize_response(self, api_client, response):
        return None



import json
import os
import re
import datetime
import tempfile

import six
from requests_toolbelt.multipart import decoder
import asposewordscloud.models
from asposewordscloud.api_client import rest


class BaseRequestObject(object):
    PRIMITIVE_TYPES = (float, bool, bytes, six.text_type) + six.integer_types
    NATIVE_TYPES_MAPPING = {
        'int': int,
        'long': int if six.PY3 else long,  # pylint: disable=undefined-variable
        'float': float,
        'str': str,
        'bool': bool,
        'date': datetime.date,
        'datetime': datetime.datetime,
        'object': object,
    }

    def getparts(self, response):
        return decoder.MultipartDecoder(response.data, response.getheader('Content-Type'), 'UTF-8').parts

    def deserialize(self, response_data, klass, api_client):
        """Deserializes dict, list, str into an object.

        :param data: dict, list or str.
        :param klass: class literal, or string of class name.

        :return: object.
        """
        if response_data is None:
            return None

        data = response_data

        if isinstance(response_data, rest.RESTResponse):
            # fetch data from response object
            data = response_data.data
            if six.PY3:
                data = response_data.data.decode('utf8')
            try:
                data = json.loads(data)
            except:
                pass

        if type(klass) == str:
            if klass.startswith('list['):
                sub_kls = re.match(r'list\[(.*)\]', klass).group(1)
                return [self.deserialize(sub_data, sub_kls, api_client)
                        for sub_data in data]

            if klass.startswith('dict('):
                sub_kls = re.match(r'dict\(([^,]*), (.*)\)', klass).group(2)
                return {k: self.deserialize(v, sub_kls, api_client)
                        for k, v in six.iteritems(data)}

            # convert str to class
            if klass in self.NATIVE_TYPES_MAPPING:
                klass = self.NATIVE_TYPES_MAPPING[klass]
            else:
                klass = getattr(asposewordscloud.models, klass)

        if klass in self.PRIMITIVE_TYPES:
            return self.__deserialize_primitive(data, klass)
        elif klass == object:
            return self.__deserialize_object(data)
        elif klass == datetime.date:
            return self.__deserialize_date(data)
        elif klass == datetime.datetime:
            return self.__deserialize_datatime(data)
        else:
            return self.__deserialize_model(data, klass, api_client)


    def deserialize_file(self, data, headers, api_client):
        """Deserializes body to file

        Saves response body into a file in a temporary folder,
        using the filename from the `Content-Disposition` header if provided.

        :param response:  RESTResponse.
        :return: file path.
        """
        fd, path = tempfile.mkstemp(dir=api_client.configuration.temp_folder_path)
        os.close(fd)
        os.remove(path)

        if 'Content-Disposition' in headers.keys():
            content_disposition = headers["Content-Disposition"]
            filename = re.search(r'filename=[\'"]?([^\'"\s]+)[\'"]?',
                                 content_disposition).group(1)
            filename = filename.replace('/', '_')
            path = os.path.join(os.path.dirname(path), filename)

        with open(path, "wb") as f:
            f.write(data)

        return path

    def __deserialize_primitive(self, data, klass):
        """Deserializes string to primitive type.

        :param data: str.
        :param klass: class literal.

        :return: int, long, float, str, bool.
        """
        try:
            return klass(data)
        except UnicodeEncodeError:
            if not six.PY3:
                return data.encode('utf8')
            return six.u(data)
        except TypeError:
            return data

    def __deserialize_object(self, value):
        """Return a original value.

        :return: object.
        """
        return value

    def __deserialize_date(self, string):
        """Deserializes string to date.

        :param string: str.
        :return: date.
        """
        try:
            from dateutil.parser import parse
            return parse(string).date()
        except ImportError:
            return string
        except ValueError:
            raise rest.ApiException(
                status=0,
                reason="Failed to parse `{0}` as date object".format(string)
            )

    def __deserialize_datatime(self, string):
        """Deserializes string to datetime.

        The string should be in iso8601 datetime format.

        :param string: str.
        :return: datetime.
        """
        try:
            from dateutil.parser import parse
            return parse(string)
        except ImportError:
            return string
        except ValueError:
            raise rest.ApiException(
                status=0,
                reason=(
                    "Failed to parse `{0}` as datetime object"
                    .format(string)
                )
            )

    def __deserialize_model(self, data, klass, api_client):
        """Deserializes list or dict to model.

        :param data: dict, list.
        :param klass: class literal.
        :return: model object.
        """
        if klass is None: 
            return data

        if not klass.swagger_types and not hasattr(klass,
                                                   'get_real_child_model'):
            return data

        kwargs = {}
        if klass.swagger_types is not None:
            for attr, attr_type in six.iteritems(klass.swagger_types):
                if (data is not None and
                        klass.attribute_map[attr] in data and
                        isinstance(data, (list, dict))):
                    value = data[klass.attribute_map[attr]]
                    kwargs[attr] = self.deserialize(value, attr_type, api_client)

        instance = klass(**kwargs)

        if hasattr(instance, 'get_real_child_model'):
            klass_name = instance.get_real_child_model(data)
            if klass_name:
                instance = self.deserialize(data, klass_name, api_client)
        return instance



from test.api.bookmark.test_bookmark import TestBookmark
from test.api.compatibility.test_compatibility import TestCompatibility
from test.api.document.test_append_document import TestAppendDocument
from test.api.document.test_classification import TestClassification
from test.api.document.test_comment import TestComment
from test.api.document.test_compare_document import TestCompareDocument
from test.api.document.test_convert_document import TestConvertDocument
from test.api.document.test_document import TestDocument
from test.api.document.test_document_statistics import TestDocumentStatistics
from test.api.document.test_document_with_format import TestDocumentWithFormat
from test.api.document.test_load_web_document import TestLoadWebDocument
from test.api.document.test_revisions import TestRevisions
from test.api.document.test_split_document_to_format import TestSplitDocumentToFormat
from test.api.document_properties.test_document_properties import TestDocumentProperties
from test.api.document_protection.test_document_protection import TestDocumentProtection
from test.api.drawing.test_drawing_objects import TestDrawingObjects
from test.api.field.test_field import TestField
from test.api.field.test_form_field import TestFormField
from test.api.font.test_font import TestFont
from test.api.footnote.test_footnote import TestFootnote
from test.api.header_footer.test_header_footer import TestHeaderFooter
from test.api.hyperlink.test_hyperlink import TestHyperlink
from test.api.lists.test_lists import TestLists
from test.api.macros.test_macros import TestMacros
from test.api.mail_merge.test_execute_mail_merge import TestExecuteMailMerge
from test.api.mail_merge.test_execute_template import TestExecuteTemplate
from test.api.mail_merge.test_mail_merge_fileds import TestMailMergeFileds
from test.api.math_object.test_math_object import TestMathObject
from test.api.page_setup.test_page_setup import TestPageSetup
from test.api.paragraph.test_paragraph import TestParagraph
from test.api.range.test_range import TestRange
from test.api.report.test_build_report import TestBuildReport
from test.api.run.test_run import TestRun
from test.api.sections.test_section import TestSection
from test.api.storage.test_file import TestFile
from test.api.storage.test_folder import TestFolder
from test.api.styles.test_styles import TestStyles
from test.api.table.test_table import TestTable
from test.api.table.test_table_border import TestTableBorder
from test.api.text.test_text import TestText
from test.api.watermark.test_watermark import TestWatermark
from test.test_url_encode import TestUrlEncode
from test.test_readme import TestReadme
from test.test_batch import TestBatch
from test.test_examples import TestExamples


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="mhtml_save_options_data.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class MhtmlSaveOptionsData(object):
    """Container class for mhtml save options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_embedding_post_script_fonts': 'bool',
        'custom_time_zone_info_data': 'TimeZoneInfoData',
        'dml3_d_effects_rendering_mode': 'str',
        'dml_effects_rendering_mode': 'str',
        'dml_rendering_mode': 'str',
        'file_name': 'str',
        'save_format': 'str',
        'update_created_time_property': 'bool',
        'update_fields': 'bool',
        'update_last_printed_property': 'bool',
        'update_last_saved_time_property': 'bool',
        'update_sdt_content': 'bool',
        'zip_output': 'bool',
        'allow_negative_indent': 'bool',
        'css_class_name_prefix': 'str',
        'css_style_sheet_file_name': 'str',
        'css_style_sheet_type': 'str',
        'document_split_criteria': 'str',
        'document_split_heading_level': 'int',
        'encoding': 'str',
        'export_document_properties': 'bool',
        'export_drop_down_form_field_as_text': 'bool',
        'export_font_resources': 'bool',
        'export_fonts_as_base64': 'bool',
        'export_headers_footers_mode': 'str',
        'export_images_as_base64': 'bool',
        'export_language_information': 'bool',
        'export_list_labels': 'str',
        'export_original_url_for_linked_images': 'bool',
        'export_page_margins': 'bool',
        'export_page_setup': 'bool',
        'export_relative_font_size': 'bool',
        'export_roundtrip_information': 'bool',
        'export_text_box_as_svg': 'bool',
        'export_text_input_form_field_as_text': 'bool',
        'export_toc_page_numbers': 'bool',
        'export_xhtml_transitional': 'bool',
        'font_resources_subsetting_size_threshold': 'int',
        'fonts_folder': 'str',
        'fonts_folder_alias': 'str',
        'html_version': 'str',
        'image_resolution': 'int',
        'images_folder': 'str',
        'images_folder_alias': 'str',
        'metafile_format': 'str',
        'office_math_output_mode': 'str',
        'pretty_format': 'bool',
        'resolve_font_names': 'bool',
        'resource_folder': 'str',
        'resource_folder_alias': 'str',
        'scale_image_to_shape_size': 'bool',
        'table_width_output_mode': 'str',
        'export_cid_urls_for_mhtml_resources': 'bool'
    }

    attribute_map = {
        'allow_embedding_post_script_fonts': 'AllowEmbeddingPostScriptFonts',
        'custom_time_zone_info_data': 'CustomTimeZoneInfoData',
        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
        'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
        'dml_rendering_mode': 'DmlRenderingMode',
        'file_name': 'FileName',
        'save_format': 'SaveFormat',
        'update_created_time_property': 'UpdateCreatedTimeProperty',
        'update_fields': 'UpdateFields',
        'update_last_printed_property': 'UpdateLastPrintedProperty',
        'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
        'update_sdt_content': 'UpdateSdtContent',
        'zip_output': 'ZipOutput',
        'allow_negative_indent': 'AllowNegativeIndent',
        'css_class_name_prefix': 'CssClassNamePrefix',
        'css_style_sheet_file_name': 'CssStyleSheetFileName',
        'css_style_sheet_type': 'CssStyleSheetType',
        'document_split_criteria': 'DocumentSplitCriteria',
        'document_split_heading_level': 'DocumentSplitHeadingLevel',
        'encoding': 'Encoding',
        'export_document_properties': 'ExportDocumentProperties',
        'export_drop_down_form_field_as_text': 'ExportDropDownFormFieldAsText',
        'export_font_resources': 'ExportFontResources',
        'export_fonts_as_base64': 'ExportFontsAsBase64',
        'export_headers_footers_mode': 'ExportHeadersFootersMode',
        'export_images_as_base64': 'ExportImagesAsBase64',
        'export_language_information': 'ExportLanguageInformation',
        'export_list_labels': 'ExportListLabels',
        'export_original_url_for_linked_images': 'ExportOriginalUrlForLinkedImages',
        'export_page_margins': 'ExportPageMargins',
        'export_page_setup': 'ExportPageSetup',
        'export_relative_font_size': 'ExportRelativeFontSize',
        'export_roundtrip_information': 'ExportRoundtripInformation',
        'export_text_box_as_svg': 'ExportTextBoxAsSvg',
        'export_text_input_form_field_as_text': 'ExportTextInputFormFieldAsText',
        'export_toc_page_numbers': 'ExportTocPageNumbers',
        'export_xhtml_transitional': 'ExportXhtmlTransitional',
        'font_resources_subsetting_size_threshold': 'FontResourcesSubsettingSizeThreshold',
        'fonts_folder': 'FontsFolder',
        'fonts_folder_alias': 'FontsFolderAlias',
        'html_version': 'HtmlVersion',
        'image_resolution': 'ImageResolution',
        'images_folder': 'ImagesFolder',
        'images_folder_alias': 'ImagesFolderAlias',
        'metafile_format': 'MetafileFormat',
        'office_math_output_mode': 'OfficeMathOutputMode',
        'pretty_format': 'PrettyFormat',
        'resolve_font_names': 'ResolveFontNames',
        'resource_folder': 'ResourceFolder',
        'resource_folder_alias': 'ResourceFolderAlias',
        'scale_image_to_shape_size': 'ScaleImageToShapeSize',
        'table_width_output_mode': 'TableWidthOutputMode',
        'export_cid_urls_for_mhtml_resources': 'ExportCidUrlsForMhtmlResources'
    }

    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, allow_negative_indent=None, css_class_name_prefix=None, css_style_sheet_file_name=None, css_style_sheet_type=None, document_split_criteria=None, document_split_heading_level=None, encoding=None, export_document_properties=None, export_drop_down_form_field_as_text=None, export_font_resources=None, export_fonts_as_base64=None, export_headers_footers_mode=None, export_images_as_base64=None, export_language_information=None, export_list_labels=None, export_original_url_for_linked_images=None, export_page_margins=None, export_page_setup=None, export_relative_font_size=None, export_roundtrip_information=None, export_text_box_as_svg=None, export_text_input_form_field_as_text=None, export_toc_page_numbers=None, export_xhtml_transitional=None, font_resources_subsetting_size_threshold=None, fonts_folder=None, fonts_folder_alias=None, html_version=None, image_resolution=None, images_folder=None, images_folder_alias=None, metafile_format=None, office_math_output_mode=None, pretty_format=None, resolve_font_names=None, resource_folder=None, resource_folder_alias=None, scale_image_to_shape_size=None, table_width_output_mode=None, export_cid_urls_for_mhtml_resources=None):  # noqa: E501
        """MhtmlSaveOptionsData - a model defined in Swagger"""  # noqa: E501

        self._allow_embedding_post_script_fonts = None
        self._custom_time_zone_info_data = None
        self._dml3_d_effects_rendering_mode = None
        self._dml_effects_rendering_mode = None
        self._dml_rendering_mode = None
        self._file_name = None
        self._save_format = None
        self._update_created_time_property = None
        self._update_fields = None
        self._update_last_printed_property = None
        self._update_last_saved_time_property = None
        self._update_sdt_content = None
        self._zip_output = None
        self._allow_negative_indent = None
        self._css_class_name_prefix = None
        self._css_style_sheet_file_name = None
        self._css_style_sheet_type = None
        self._document_split_criteria = None
        self._document_split_heading_level = None
        self._encoding = None
        self._export_document_properties = None
        self._export_drop_down_form_field_as_text = None
        self._export_font_resources = None
        self._export_fonts_as_base64 = None
        self._export_headers_footers_mode = None
        self._export_images_as_base64 = None
        self._export_language_information = None
        self._export_list_labels = None
        self._export_original_url_for_linked_images = None
        self._export_page_margins = None
        self._export_page_setup = None
        self._export_relative_font_size = None
        self._export_roundtrip_information = None
        self._export_text_box_as_svg = None
        self._export_text_input_form_field_as_text = None
        self._export_toc_page_numbers = None
        self._export_xhtml_transitional = None
        self._font_resources_subsetting_size_threshold = None
        self._fonts_folder = None
        self._fonts_folder_alias = None
        self._html_version = None
        self._image_resolution = None
        self._images_folder = None
        self._images_folder_alias = None
        self._metafile_format = None
        self._office_math_output_mode = None
        self._pretty_format = None
        self._resolve_font_names = None
        self._resource_folder = None
        self._resource_folder_alias = None
        self._scale_image_to_shape_size = None
        self._table_width_output_mode = None
        self._export_cid_urls_for_mhtml_resources = None
        self.discriminator = None

        if allow_embedding_post_script_fonts is not None:
            self.allow_embedding_post_script_fonts = allow_embedding_post_script_fonts
        if custom_time_zone_info_data is not None:
            self.custom_time_zone_info_data = custom_time_zone_info_data
        if dml3_d_effects_rendering_mode is not None:
            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
        if dml_effects_rendering_mode is not None:
            self.dml_effects_rendering_mode = dml_effects_rendering_mode
        if dml_rendering_mode is not None:
            self.dml_rendering_mode = dml_rendering_mode
        if file_name is not None:
            self.file_name = file_name
        if save_format is not None:
            self.save_format = save_format
        if update_created_time_property is not None:
            self.update_created_time_property = update_created_time_property
        if update_fields is not None:
            self.update_fields = update_fields
        if update_last_printed_property is not None:
            self.update_last_printed_property = update_last_printed_property
        if update_last_saved_time_property is not None:
            self.update_last_saved_time_property = update_last_saved_time_property
        if update_sdt_content is not None:
            self.update_sdt_content = update_sdt_content
        if zip_output is not None:
            self.zip_output = zip_output
        if allow_negative_indent is not None:
            self.allow_negative_indent = allow_negative_indent
        if css_class_name_prefix is not None:
            self.css_class_name_prefix = css_class_name_prefix
        if css_style_sheet_file_name is not None:
            self.css_style_sheet_file_name = css_style_sheet_file_name
        if css_style_sheet_type is not None:
            self.css_style_sheet_type = css_style_sheet_type
        if document_split_criteria is not None:
            self.document_split_criteria = document_split_criteria
        if document_split_heading_level is not None:
            self.document_split_heading_level = document_split_heading_level
        if encoding is not None:
            self.encoding = encoding
        if export_document_properties is not None:
            self.export_document_properties = export_document_properties
        if export_drop_down_form_field_as_text is not None:
            self.export_drop_down_form_field_as_text = export_drop_down_form_field_as_text
        if export_font_resources is not None:
            self.export_font_resources = export_font_resources
        if export_fonts_as_base64 is not None:
            self.export_fonts_as_base64 = export_fonts_as_base64
        if export_headers_footers_mode is not None:
            self.export_headers_footers_mode = export_headers_footers_mode
        if export_images_as_base64 is not None:
            self.export_images_as_base64 = export_images_as_base64
        if export_language_information is not None:
            self.export_language_information = export_language_information
        if export_list_labels is not None:
            self.export_list_labels = export_list_labels
        if export_original_url_for_linked_images is not None:
            self.export_original_url_for_linked_images = export_original_url_for_linked_images
        if export_page_margins is not None:
            self.export_page_margins = export_page_margins
        if export_page_setup is not None:
            self.export_page_setup = export_page_setup
        if export_relative_font_size is not None:
            self.export_relative_font_size = export_relative_font_size
        if export_roundtrip_information is not None:
            self.export_roundtrip_information = export_roundtrip_information
        if export_text_box_as_svg is not None:
            self.export_text_box_as_svg = export_text_box_as_svg
        if export_text_input_form_field_as_text is not None:
            self.export_text_input_form_field_as_text = export_text_input_form_field_as_text
        if export_toc_page_numbers is not None:
            self.export_toc_page_numbers = export_toc_page_numbers
        if export_xhtml_transitional is not None:
            self.export_xhtml_transitional = export_xhtml_transitional
        if font_resources_subsetting_size_threshold is not None:
            self.font_resources_subsetting_size_threshold = font_resources_subsetting_size_threshold
        if fonts_folder is not None:
            self.fonts_folder = fonts_folder
        if fonts_folder_alias is not None:
            self.fonts_folder_alias = fonts_folder_alias
        if html_version is not None:
            self.html_version = html_version
        if image_resolution is not None:
            self.image_resolution = image_resolution
        if images_folder is not None:
            self.images_folder = images_folder
        if images_folder_alias is not None:
            self.images_folder_alias = images_folder_alias
        if metafile_format is not None:
            self.metafile_format = metafile_format
        if office_math_output_mode is not None:
            self.office_math_output_mode = office_math_output_mode
        if pretty_format is not None:
            self.pretty_format = pretty_format
        if resolve_font_names is not None:
            self.resolve_font_names = resolve_font_names
        if resource_folder is not None:
            self.resource_folder = resource_folder
        if resource_folder_alias is not None:
            self.resource_folder_alias = resource_folder_alias
        if scale_image_to_shape_size is not None:
            self.scale_image_to_shape_size = scale_image_to_shape_size
        if table_width_output_mode is not None:
            self.table_width_output_mode = table_width_output_mode
        if export_cid_urls_for_mhtml_resources is not None:
            self.export_cid_urls_for_mhtml_resources = export_cid_urls_for_mhtml_resources

    @property
    def allow_embedding_post_script_fonts(self):
        """Gets the allow_embedding_post_script_fonts of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a boolean value indicating whether to allow embedding fonts with PostScript outlines when embedding TrueType fonts in a document upon it is saved. The default value is false..  # noqa: E501

        :return: The allow_embedding_post_script_fonts of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._allow_embedding_post_script_fonts

    @allow_embedding_post_script_fonts.setter
    def allow_embedding_post_script_fonts(self, allow_embedding_post_script_fonts):
        """Sets the allow_embedding_post_script_fonts of this MhtmlSaveOptionsData.

        Gets or sets a boolean value indicating whether to allow embedding fonts with PostScript outlines when embedding TrueType fonts in a document upon it is saved. The default value is false..  # noqa: E501

        :param allow_embedding_post_script_fonts: The allow_embedding_post_script_fonts of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._allow_embedding_post_script_fonts = allow_embedding_post_script_fonts

    @property
    def custom_time_zone_info_data(self):
        """Gets the custom_time_zone_info_data of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets CustomTimeZoneInfo.  # noqa: E501

        :return: The custom_time_zone_info_data of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: TimeZoneInfoData
        """
        return self._custom_time_zone_info_data

    @custom_time_zone_info_data.setter
    def custom_time_zone_info_data(self, custom_time_zone_info_data):
        """Sets the custom_time_zone_info_data of this MhtmlSaveOptionsData.

        Gets or sets CustomTimeZoneInfo.  # noqa: E501

        :param custom_time_zone_info_data: The custom_time_zone_info_data of this MhtmlSaveOptionsData.  # noqa: E501
        :type: TimeZoneInfoData
        """
        self._custom_time_zone_info_data = custom_time_zone_info_data

    @property
    def dml3_d_effects_rendering_mode(self):
        """Gets the dml3_d_effects_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the value determining how 3D effects are rendered.  # noqa: E501

        :return: The dml3_d_effects_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml3_d_effects_rendering_mode

    @dml3_d_effects_rendering_mode.setter
    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
        """Sets the dml3_d_effects_rendering_mode of this MhtmlSaveOptionsData.

        Gets or sets the value determining how 3D effects are rendered.  # noqa: E501

        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Basic", "Advanced"]  # noqa: E501
        if not dml3_d_effects_rendering_mode.isdigit():
            if dml3_d_effects_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(dml3_d_effects_rendering_mode, allowed_values))
            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
        else:
            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]

    @property
    def dml_effects_rendering_mode(self):
        """Gets the dml_effects_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501

        :return: The dml_effects_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml_effects_rendering_mode

    @dml_effects_rendering_mode.setter
    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
        """Sets the dml_effects_rendering_mode of this MhtmlSaveOptionsData.

        Gets or sets the value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501

        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._dml_effects_rendering_mode = dml_effects_rendering_mode

    @property
    def dml_rendering_mode(self):
        """Gets the dml_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how DrawingML shapes are rendered.  # noqa: E501

        :return: The dml_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml_rendering_mode

    @dml_rendering_mode.setter
    def dml_rendering_mode(self, dml_rendering_mode):
        """Sets the dml_rendering_mode of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how DrawingML shapes are rendered.  # noqa: E501

        :param dml_rendering_mode: The dml_rendering_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._dml_rendering_mode = dml_rendering_mode

    @property
    def file_name(self):
        """Gets the file_name of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the name of destination file.  # noqa: E501

        :return: The file_name of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this MhtmlSaveOptionsData.

        Gets or sets the name of destination file.  # noqa: E501

        :param file_name: The file_name of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._file_name = file_name

    @property
    def save_format(self):
        """Gets the save_format of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the format of save.  # noqa: E501

        :return: The save_format of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._save_format

    @save_format.setter
    def save_format(self, save_format):
        """Sets the save_format of this MhtmlSaveOptionsData.

        Gets or sets the format of save.  # noqa: E501

        :param save_format: The save_format of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._save_format = save_format

    @property
    def update_created_time_property(self):
        """Gets the update_created_time_property of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.CreatedTime property is updated before saving. Default value is false.  # noqa: E501

        :return: The update_created_time_property of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_created_time_property

    @update_created_time_property.setter
    def update_created_time_property(self, update_created_time_property):
        """Sets the update_created_time_property of this MhtmlSaveOptionsData.

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.CreatedTime property is updated before saving. Default value is false.  # noqa: E501

        :param update_created_time_property: The update_created_time_property of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_created_time_property = update_created_time_property

    @property
    def update_fields(self):
        """Gets the update_fields of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether fields should be updated before saving the document to a fixed page format. The default value is true.  # noqa: E501

        :return: The update_fields of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_fields

    @update_fields.setter
    def update_fields(self, update_fields):
        """Sets the update_fields of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether fields should be updated before saving the document to a fixed page format. The default value is true.  # noqa: E501

        :param update_fields: The update_fields of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_fields = update_fields

    @property
    def update_last_printed_property(self):
        """Gets the update_last_printed_property of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501

        :return: The update_last_printed_property of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_last_printed_property

    @update_last_printed_property.setter
    def update_last_printed_property(self, update_last_printed_property):
        """Sets the update_last_printed_property of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501

        :param update_last_printed_property: The update_last_printed_property of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_last_printed_property = update_last_printed_property

    @property
    def update_last_saved_time_property(self):
        """Gets the update_last_saved_time_property of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501

        :return: The update_last_saved_time_property of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_last_saved_time_property

    @update_last_saved_time_property.setter
    def update_last_saved_time_property(self, update_last_saved_time_property):
        """Sets the update_last_saved_time_property of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501

        :param update_last_saved_time_property: The update_last_saved_time_property of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_last_saved_time_property = update_last_saved_time_property

    @property
    def update_sdt_content(self):
        """Gets the update_sdt_content of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether content of StructuredDocumentTag is updated before saving.  # noqa: E501

        :return: The update_sdt_content of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_sdt_content

    @update_sdt_content.setter
    def update_sdt_content(self, update_sdt_content):
        """Sets the update_sdt_content of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether content of StructuredDocumentTag is updated before saving.  # noqa: E501

        :param update_sdt_content: The update_sdt_content of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_sdt_content = update_sdt_content

    @property
    def zip_output(self):
        """Gets the zip_output of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to zip output or not. The default value is false.  # noqa: E501

        :return: The zip_output of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._zip_output

    @zip_output.setter
    def zip_output(self, zip_output):
        """Sets the zip_output of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to zip output or not. The default value is false.  # noqa: E501

        :param zip_output: The zip_output of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._zip_output = zip_output

    @property
    def allow_negative_indent(self):
        """Gets the allow_negative_indent of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether negative left and right indents of paragraphs are allowed (not normalized).  # noqa: E501

        :return: The allow_negative_indent of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._allow_negative_indent

    @allow_negative_indent.setter
    def allow_negative_indent(self, allow_negative_indent):
        """Sets the allow_negative_indent of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether negative left and right indents of paragraphs are allowed (not normalized).  # noqa: E501

        :param allow_negative_indent: The allow_negative_indent of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._allow_negative_indent = allow_negative_indent

    @property
    def css_class_name_prefix(self):
        """Gets the css_class_name_prefix of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the prefix which is added to all CSS class names. The default value is an empty string and generated CSS class names have no common prefix. If this value is not empty, all CSS classes generated by Aspose.Words will start with the specified prefix.This might be useful, for example, if you add custom CSS to generated documents and want to prevent class name conflicts. If the value is not null or empty, it must be a valid CSS identifier.  # noqa: E501

        :return: The css_class_name_prefix of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._css_class_name_prefix

    @css_class_name_prefix.setter
    def css_class_name_prefix(self, css_class_name_prefix):
        """Sets the css_class_name_prefix of this MhtmlSaveOptionsData.

        Gets or sets the prefix which is added to all CSS class names. The default value is an empty string and generated CSS class names have no common prefix. If this value is not empty, all CSS classes generated by Aspose.Words will start with the specified prefix.This might be useful, for example, if you add custom CSS to generated documents and want to prevent class name conflicts. If the value is not null or empty, it must be a valid CSS identifier.  # noqa: E501

        :param css_class_name_prefix: The css_class_name_prefix of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._css_class_name_prefix = css_class_name_prefix

    @property
    def css_style_sheet_file_name(self):
        """Gets the css_style_sheet_file_name of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the name of the CSS file written when the document is exported to HTML.  # noqa: E501

        :return: The css_style_sheet_file_name of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._css_style_sheet_file_name

    @css_style_sheet_file_name.setter
    def css_style_sheet_file_name(self, css_style_sheet_file_name):
        """Sets the css_style_sheet_file_name of this MhtmlSaveOptionsData.

        Gets or sets the name of the CSS file written when the document is exported to HTML.  # noqa: E501

        :param css_style_sheet_file_name: The css_style_sheet_file_name of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._css_style_sheet_file_name = css_style_sheet_file_name

    @property
    def css_style_sheet_type(self):
        """Gets the css_style_sheet_type of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how the CSS styles are exported.  # noqa: E501

        :return: The css_style_sheet_type of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._css_style_sheet_type

    @css_style_sheet_type.setter
    def css_style_sheet_type(self, css_style_sheet_type):
        """Sets the css_style_sheet_type of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how the CSS styles are exported.  # noqa: E501

        :param css_style_sheet_type: The css_style_sheet_type of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._css_style_sheet_type = css_style_sheet_type

    @property
    def document_split_criteria(self):
        """Gets the document_split_criteria of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how the document should be split when saving.  # noqa: E501

        :return: The document_split_criteria of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._document_split_criteria

    @document_split_criteria.setter
    def document_split_criteria(self, document_split_criteria):
        """Sets the document_split_criteria of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how the document should be split when saving.  # noqa: E501

        :param document_split_criteria: The document_split_criteria of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._document_split_criteria = document_split_criteria

    @property
    def document_split_heading_level(self):
        """Gets the document_split_heading_level of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the maximum level of headings at which to split the document.  # noqa: E501

        :return: The document_split_heading_level of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._document_split_heading_level

    @document_split_heading_level.setter
    def document_split_heading_level(self, document_split_heading_level):
        """Sets the document_split_heading_level of this MhtmlSaveOptionsData.

        Gets or sets the maximum level of headings at which to split the document.  # noqa: E501

        :param document_split_heading_level: The document_split_heading_level of this MhtmlSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._document_split_heading_level = document_split_heading_level

    @property
    def encoding(self):
        """Gets the encoding of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the character encoding to use when exporting.  # noqa: E501

        :return: The encoding of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this MhtmlSaveOptionsData.

        Gets or sets the character encoding to use when exporting.  # noqa: E501

        :param encoding: The encoding of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._encoding = encoding

    @property
    def export_document_properties(self):
        """Gets the export_document_properties of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to export built-in and custom document properties.  # noqa: E501

        :return: The export_document_properties of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_document_properties

    @export_document_properties.setter
    def export_document_properties(self, export_document_properties):
        """Sets the export_document_properties of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to export built-in and custom document properties.  # noqa: E501

        :param export_document_properties: The export_document_properties of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_document_properties = export_document_properties

    @property
    def export_drop_down_form_field_as_text(self):
        """Gets the export_drop_down_form_field_as_text of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the flag, that controls how drop-down form fields are saved to HTML. The default value is false.  # noqa: E501

        :return: The export_drop_down_form_field_as_text of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_drop_down_form_field_as_text

    @export_drop_down_form_field_as_text.setter
    def export_drop_down_form_field_as_text(self, export_drop_down_form_field_as_text):
        """Sets the export_drop_down_form_field_as_text of this MhtmlSaveOptionsData.

        Gets or sets the flag, that controls how drop-down form fields are saved to HTML. The default value is false.  # noqa: E501

        :param export_drop_down_form_field_as_text: The export_drop_down_form_field_as_text of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_drop_down_form_field_as_text = export_drop_down_form_field_as_text

    @property
    def export_font_resources(self):
        """Gets the export_font_resources of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether font resources should be exported.  # noqa: E501

        :return: The export_font_resources of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_font_resources

    @export_font_resources.setter
    def export_font_resources(self, export_font_resources):
        """Sets the export_font_resources of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether font resources should be exported.  # noqa: E501

        :param export_font_resources: The export_font_resources of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_font_resources = export_font_resources

    @property
    def export_fonts_as_base64(self):
        """Gets the export_fonts_as_base64 of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether fonts resources should be embedded to HTML in Base64 encoding. The default value is false.  # noqa: E501

        :return: The export_fonts_as_base64 of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_fonts_as_base64

    @export_fonts_as_base64.setter
    def export_fonts_as_base64(self, export_fonts_as_base64):
        """Sets the export_fonts_as_base64 of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether fonts resources should be embedded to HTML in Base64 encoding. The default value is false.  # noqa: E501

        :param export_fonts_as_base64: The export_fonts_as_base64 of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_fonts_as_base64 = export_fonts_as_base64

    @property
    def export_headers_footers_mode(self):
        """Gets the export_headers_footers_mode of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how headers and footers are exported.  # noqa: E501

        :return: The export_headers_footers_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._export_headers_footers_mode

    @export_headers_footers_mode.setter
    def export_headers_footers_mode(self, export_headers_footers_mode):
        """Sets the export_headers_footers_mode of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how headers and footers are exported.  # noqa: E501

        :param export_headers_footers_mode: The export_headers_footers_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._export_headers_footers_mode = export_headers_footers_mode

    @property
    def export_images_as_base64(self):
        """Gets the export_images_as_base64 of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether images are saved in Base64 format.  # noqa: E501

        :return: The export_images_as_base64 of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_images_as_base64

    @export_images_as_base64.setter
    def export_images_as_base64(self, export_images_as_base64):
        """Sets the export_images_as_base64 of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether images are saved in Base64 format.  # noqa: E501

        :param export_images_as_base64: The export_images_as_base64 of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_images_as_base64 = export_images_as_base64

    @property
    def export_language_information(self):
        """Gets the export_language_information of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether language information is exported.  # noqa: E501

        :return: The export_language_information of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_language_information

    @export_language_information.setter
    def export_language_information(self, export_language_information):
        """Sets the export_language_information of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether language information is exported.  # noqa: E501

        :param export_language_information: The export_language_information of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_language_information = export_language_information

    @property
    def export_list_labels(self):
        """Gets the export_list_labels of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how list labels are exported.  # noqa: E501

        :return: The export_list_labels of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._export_list_labels

    @export_list_labels.setter
    def export_list_labels(self, export_list_labels):
        """Sets the export_list_labels of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how list labels are exported.  # noqa: E501

        :param export_list_labels: The export_list_labels of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._export_list_labels = export_list_labels

    @property
    def export_original_url_for_linked_images(self):
        """Gets the export_original_url_for_linked_images of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the original URL should be used as the URL of the linked images. The default value is false.  # noqa: E501

        :return: The export_original_url_for_linked_images of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_original_url_for_linked_images

    @export_original_url_for_linked_images.setter
    def export_original_url_for_linked_images(self, export_original_url_for_linked_images):
        """Sets the export_original_url_for_linked_images of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether the original URL should be used as the URL of the linked images. The default value is false.  # noqa: E501

        :param export_original_url_for_linked_images: The export_original_url_for_linked_images of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_original_url_for_linked_images = export_original_url_for_linked_images

    @property
    def export_page_margins(self):
        """Gets the export_page_margins of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether page margins are exported to HTML, MHTML or EPUB. The default value is false.  # noqa: E501

        :return: The export_page_margins of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_page_margins

    @export_page_margins.setter
    def export_page_margins(self, export_page_margins):
        """Sets the export_page_margins of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether page margins are exported to HTML, MHTML or EPUB. The default value is false.  # noqa: E501

        :param export_page_margins: The export_page_margins of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_page_margins = export_page_margins

    @property
    def export_page_setup(self):
        """Gets the export_page_setup of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether page setup is exported.  # noqa: E501

        :return: The export_page_setup of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_page_setup

    @export_page_setup.setter
    def export_page_setup(self, export_page_setup):
        """Sets the export_page_setup of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether page setup is exported.  # noqa: E501

        :param export_page_setup: The export_page_setup of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_page_setup = export_page_setup

    @property
    def export_relative_font_size(self):
        """Gets the export_relative_font_size of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether font sizes should be output in relative units when saving.  # noqa: E501

        :return: The export_relative_font_size of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_relative_font_size

    @export_relative_font_size.setter
    def export_relative_font_size(self, export_relative_font_size):
        """Sets the export_relative_font_size of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether font sizes should be output in relative units when saving.  # noqa: E501

        :param export_relative_font_size: The export_relative_font_size of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_relative_font_size = export_relative_font_size

    @property
    def export_roundtrip_information(self):
        """Gets the export_roundtrip_information of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to write the roundtrip information when saving to HTML. The default value is true.  # noqa: E501

        :return: The export_roundtrip_information of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_roundtrip_information

    @export_roundtrip_information.setter
    def export_roundtrip_information(self, export_roundtrip_information):
        """Sets the export_roundtrip_information of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to write the roundtrip information when saving to HTML. The default value is true.  # noqa: E501

        :param export_roundtrip_information: The export_roundtrip_information of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_roundtrip_information = export_roundtrip_information

    @property
    def export_text_box_as_svg(self):
        """Gets the export_text_box_as_svg of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the flag, that controls how textboxes represented by Aspose.Words.Drawing.Shape are saved to HTML, MHTML or EPUB. The default value is false. When set to true, exports textboxes as inline "svg" elements. When false, exports as "image" elements.  # noqa: E501

        :return: The export_text_box_as_svg of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_text_box_as_svg

    @export_text_box_as_svg.setter
    def export_text_box_as_svg(self, export_text_box_as_svg):
        """Sets the export_text_box_as_svg of this MhtmlSaveOptionsData.

        Gets or sets the flag, that controls how textboxes represented by Aspose.Words.Drawing.Shape are saved to HTML, MHTML or EPUB. The default value is false. When set to true, exports textboxes as inline "svg" elements. When false, exports as "image" elements.  # noqa: E501

        :param export_text_box_as_svg: The export_text_box_as_svg of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_text_box_as_svg = export_text_box_as_svg

    @property
    def export_text_input_form_field_as_text(self):
        """Gets the export_text_input_form_field_as_text of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the flag, that controls how text input form fields are saved.  # noqa: E501

        :return: The export_text_input_form_field_as_text of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_text_input_form_field_as_text

    @export_text_input_form_field_as_text.setter
    def export_text_input_form_field_as_text(self, export_text_input_form_field_as_text):
        """Sets the export_text_input_form_field_as_text of this MhtmlSaveOptionsData.

        Gets or sets the flag, that controls how text input form fields are saved.  # noqa: E501

        :param export_text_input_form_field_as_text: The export_text_input_form_field_as_text of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_text_input_form_field_as_text = export_text_input_form_field_as_text

    @property
    def export_toc_page_numbers(self):
        """Gets the export_toc_page_numbers of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to write page numbers to table of contents when saving.  # noqa: E501

        :return: The export_toc_page_numbers of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_toc_page_numbers

    @export_toc_page_numbers.setter
    def export_toc_page_numbers(self, export_toc_page_numbers):
        """Sets the export_toc_page_numbers of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to write page numbers to table of contents when saving.  # noqa: E501

        :param export_toc_page_numbers: The export_toc_page_numbers of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_toc_page_numbers = export_toc_page_numbers

    @property
    def export_xhtml_transitional(self):
        """Gets the export_xhtml_transitional of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to write the DOCTYPE declaration when saving.  # noqa: E501

        :return: The export_xhtml_transitional of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_xhtml_transitional

    @export_xhtml_transitional.setter
    def export_xhtml_transitional(self, export_xhtml_transitional):
        """Sets the export_xhtml_transitional of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to write the DOCTYPE declaration when saving.  # noqa: E501

        :param export_xhtml_transitional: The export_xhtml_transitional of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_xhtml_transitional = export_xhtml_transitional

    @property
    def font_resources_subsetting_size_threshold(self):
        """Gets the font_resources_subsetting_size_threshold of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls which font resources need subsetting when saving.  # noqa: E501

        :return: The font_resources_subsetting_size_threshold of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._font_resources_subsetting_size_threshold

    @font_resources_subsetting_size_threshold.setter
    def font_resources_subsetting_size_threshold(self, font_resources_subsetting_size_threshold):
        """Sets the font_resources_subsetting_size_threshold of this MhtmlSaveOptionsData.

        Gets or sets the option that controls which font resources need subsetting when saving.  # noqa: E501

        :param font_resources_subsetting_size_threshold: The font_resources_subsetting_size_threshold of this MhtmlSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._font_resources_subsetting_size_threshold = font_resources_subsetting_size_threshold

    @property
    def fonts_folder(self):
        """Gets the fonts_folder of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the physical folder where fonts are saved when exporting a document.  # noqa: E501

        :return: The fonts_folder of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._fonts_folder

    @fonts_folder.setter
    def fonts_folder(self, fonts_folder):
        """Sets the fonts_folder of this MhtmlSaveOptionsData.

        Gets or sets the physical folder where fonts are saved when exporting a document.  # noqa: E501

        :param fonts_folder: The fonts_folder of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._fonts_folder = fonts_folder

    @property
    def fonts_folder_alias(self):
        """Gets the fonts_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the name of the folder used to construct font URIs.  # noqa: E501

        :return: The fonts_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._fonts_folder_alias

    @fonts_folder_alias.setter
    def fonts_folder_alias(self, fonts_folder_alias):
        """Sets the fonts_folder_alias of this MhtmlSaveOptionsData.

        Gets or sets the name of the folder used to construct font URIs.  # noqa: E501

        :param fonts_folder_alias: The fonts_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._fonts_folder_alias = fonts_folder_alias

    @property
    def html_version(self):
        """Gets the html_version of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the version of HTML standard, that should be used when saving the document to HTML or MHTML. Default value is Aspose.Words.Saving.HtmlVersion.Xhtml.  # noqa: E501

        :return: The html_version of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._html_version

    @html_version.setter
    def html_version(self, html_version):
        """Sets the html_version of this MhtmlSaveOptionsData.

        Gets or sets the version of HTML standard, that should be used when saving the document to HTML or MHTML. Default value is Aspose.Words.Saving.HtmlVersion.Xhtml.  # noqa: E501

        :param html_version: The html_version of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Xhtml", "Html5"]  # noqa: E501
        if not html_version.isdigit():
            if html_version not in allowed_values:
                raise ValueError(
                    "Invalid value for `html_version` ({0}), must be one of {1}"  # noqa: E501
                    .format(html_version, allowed_values))
            self._html_version = html_version
        else:
            self._html_version = allowed_values[int(html_version) if six.PY3 else long(html_version)]

    @property
    def image_resolution(self):
        """Gets the image_resolution of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the output resolution for images when exporting.  # noqa: E501

        :return: The image_resolution of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._image_resolution

    @image_resolution.setter
    def image_resolution(self, image_resolution):
        """Sets the image_resolution of this MhtmlSaveOptionsData.

        Gets or sets the output resolution for images when exporting.  # noqa: E501

        :param image_resolution: The image_resolution of this MhtmlSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._image_resolution = image_resolution

    @property
    def images_folder(self):
        """Gets the images_folder of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the physical folder where images are saved when exporting a document.  # noqa: E501

        :return: The images_folder of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._images_folder

    @images_folder.setter
    def images_folder(self, images_folder):
        """Sets the images_folder of this MhtmlSaveOptionsData.

        Gets or sets the physical folder where images are saved when exporting a document.  # noqa: E501

        :param images_folder: The images_folder of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._images_folder = images_folder

    @property
    def images_folder_alias(self):
        """Gets the images_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the name of the folder used to construct image URIs.  # noqa: E501

        :return: The images_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._images_folder_alias

    @images_folder_alias.setter
    def images_folder_alias(self, images_folder_alias):
        """Sets the images_folder_alias of this MhtmlSaveOptionsData.

        Gets or sets the name of the folder used to construct image URIs.  # noqa: E501

        :param images_folder_alias: The images_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._images_folder_alias = images_folder_alias

    @property
    def metafile_format(self):
        """Gets the metafile_format of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the options, that controls in what format metafiles are saved when exporting to HTML, MHTML, or EPUB. The default value is Aspose.Words.Saving.HtmlMetafileFormat.Png, meaning that metafiles are rendered to raster PNG images. Metafiles are not natively displayed by HTML browsers. By default, Aspose.Words converts WMF and EMF images into PNG files when exporting to HTML.Other options are to convert metafiles to SVG images or to export them as is without conversion. Some image transforms, in particular image cropping, will not be applied to metafile images if they are exported to HTML without conversion.  # noqa: E501

        :return: The metafile_format of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._metafile_format

    @metafile_format.setter
    def metafile_format(self, metafile_format):
        """Sets the metafile_format of this MhtmlSaveOptionsData.

        Gets or sets the options, that controls in what format metafiles are saved when exporting to HTML, MHTML, or EPUB. The default value is Aspose.Words.Saving.HtmlMetafileFormat.Png, meaning that metafiles are rendered to raster PNG images. Metafiles are not natively displayed by HTML browsers. By default, Aspose.Words converts WMF and EMF images into PNG files when exporting to HTML.Other options are to convert metafiles to SVG images or to export them as is without conversion. Some image transforms, in particular image cropping, will not be applied to metafile images if they are exported to HTML without conversion.  # noqa: E501

        :param metafile_format: The metafile_format of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Png", "Svg", "EmfOrWmf"]  # noqa: E501
        if not metafile_format.isdigit():
            if metafile_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `metafile_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(metafile_format, allowed_values))
            self._metafile_format = metafile_format
        else:
            self._metafile_format = allowed_values[int(metafile_format) if six.PY3 else long(metafile_format)]

    @property
    def office_math_output_mode(self):
        """Gets the office_math_output_mode of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how OfficeMath objects are exported to HTML, MHTML or EPUB. The default value is HtmlOfficeMathOutputMode.Image.  # noqa: E501

        :return: The office_math_output_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._office_math_output_mode

    @office_math_output_mode.setter
    def office_math_output_mode(self, office_math_output_mode):
        """Sets the office_math_output_mode of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how OfficeMath objects are exported to HTML, MHTML or EPUB. The default value is HtmlOfficeMathOutputMode.Image.  # noqa: E501

        :param office_math_output_mode: The office_math_output_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Image", "MathML", "Text"]  # noqa: E501
        if not office_math_output_mode.isdigit():
            if office_math_output_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `office_math_output_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(office_math_output_mode, allowed_values))
            self._office_math_output_mode = office_math_output_mode
        else:
            self._office_math_output_mode = allowed_values[int(office_math_output_mode) if six.PY3 else long(office_math_output_mode)]

    @property
    def pretty_format(self):
        """Gets the pretty_format of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to use pretty formats output.  # noqa: E501

        :return: The pretty_format of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._pretty_format

    @pretty_format.setter
    def pretty_format(self, pretty_format):
        """Sets the pretty_format of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to use pretty formats output.  # noqa: E501

        :param pretty_format: The pretty_format of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._pretty_format = pretty_format

    @property
    def resolve_font_names(self):
        """Gets the resolve_font_names of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether font family names used in the document are resolved and substituted according to FontSettings when being written into HTML-based formats. The default value is false.  # noqa: E501

        :return: The resolve_font_names of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._resolve_font_names

    @resolve_font_names.setter
    def resolve_font_names(self, resolve_font_names):
        """Sets the resolve_font_names of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether font family names used in the document are resolved and substituted according to FontSettings when being written into HTML-based formats. The default value is false.  # noqa: E501

        :param resolve_font_names: The resolve_font_names of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._resolve_font_names = resolve_font_names

    @property
    def resource_folder(self):
        """Gets the resource_folder of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the physical folder where all resources like images, fonts, and external CSS are saved when a document is exported to HTML. The default value is an empty string.  # noqa: E501

        :return: The resource_folder of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._resource_folder

    @resource_folder.setter
    def resource_folder(self, resource_folder):
        """Sets the resource_folder of this MhtmlSaveOptionsData.

        Gets or sets the physical folder where all resources like images, fonts, and external CSS are saved when a document is exported to HTML. The default value is an empty string.  # noqa: E501

        :param resource_folder: The resource_folder of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._resource_folder = resource_folder

    @property
    def resource_folder_alias(self):
        """Gets the resource_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the name of the folder used to construct URIs of all resources written into HTML document. The default value is an empty string.  # noqa: E501

        :return: The resource_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._resource_folder_alias

    @resource_folder_alias.setter
    def resource_folder_alias(self, resource_folder_alias):
        """Sets the resource_folder_alias of this MhtmlSaveOptionsData.

        Gets or sets the name of the folder used to construct URIs of all resources written into HTML document. The default value is an empty string.  # noqa: E501

        :param resource_folder_alias: The resource_folder_alias of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._resource_folder_alias = resource_folder_alias

    @property
    def scale_image_to_shape_size(self):
        """Gets the scale_image_to_shape_size of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether images are scaled by Aspose.Words to the bounding shape size when exporting.  # noqa: E501

        :return: The scale_image_to_shape_size of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._scale_image_to_shape_size

    @scale_image_to_shape_size.setter
    def scale_image_to_shape_size(self, scale_image_to_shape_size):
        """Sets the scale_image_to_shape_size of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether images are scaled by Aspose.Words to the bounding shape size when exporting.  # noqa: E501

        :param scale_image_to_shape_size: The scale_image_to_shape_size of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._scale_image_to_shape_size = scale_image_to_shape_size

    @property
    def table_width_output_mode(self):
        """Gets the table_width_output_mode of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how table, row and cell widths are exported.  # noqa: E501

        :return: The table_width_output_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._table_width_output_mode

    @table_width_output_mode.setter
    def table_width_output_mode(self, table_width_output_mode):
        """Sets the table_width_output_mode of this MhtmlSaveOptionsData.

        Gets or sets the option that controls how table, row and cell widths are exported.  # noqa: E501

        :param table_width_output_mode: The table_width_output_mode of this MhtmlSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._table_width_output_mode = table_width_output_mode

    @property
    def export_cid_urls_for_mhtml_resources(self):
        """Gets the export_cid_urls_for_mhtml_resources of this MhtmlSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to use CID (Content-ID) URLs to reference resources (images, fonts, CSS) included in MHTML documents. The default value is false.  # noqa: E501

        :return: The export_cid_urls_for_mhtml_resources of this MhtmlSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_cid_urls_for_mhtml_resources

    @export_cid_urls_for_mhtml_resources.setter
    def export_cid_urls_for_mhtml_resources(self, export_cid_urls_for_mhtml_resources):
        """Sets the export_cid_urls_for_mhtml_resources of this MhtmlSaveOptionsData.

        Gets or sets a value indicating whether to use CID (Content-ID) URLs to reference resources (images, fonts, CSS) included in MHTML documents. The default value is false.  # noqa: E501

        :param export_cid_urls_for_mhtml_resources: The export_cid_urls_for_mhtml_resources of this MhtmlSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_cid_urls_for_mhtml_resources = export_cid_urls_for_mhtml_resources


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MhtmlSaveOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="graphics_quality_options_data.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class GraphicsQualityOptionsData(object):
    """Allows to specify additional System.Drawing.Graphics quality options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compositing_mode': 'str',
        'compositing_quality': 'str',
        'interpolation_mode': 'str',
        'smoothing_mode': 'str',
        'string_format': 'StringFormatData',
        'text_rendering_hint': 'str'
    }

    attribute_map = {
        'compositing_mode': 'CompositingMode',
        'compositing_quality': 'CompositingQuality',
        'interpolation_mode': 'InterpolationMode',
        'smoothing_mode': 'SmoothingMode',
        'string_format': 'StringFormat',
        'text_rendering_hint': 'TextRenderingHint'
    }

    def __init__(self, compositing_mode=None, compositing_quality=None, interpolation_mode=None, smoothing_mode=None, string_format=None, text_rendering_hint=None):  # noqa: E501
        """GraphicsQualityOptionsData - a model defined in Swagger"""  # noqa: E501

        self._compositing_mode = None
        self._compositing_quality = None
        self._interpolation_mode = None
        self._smoothing_mode = None
        self._string_format = None
        self._text_rendering_hint = None
        self.discriminator = None

        if compositing_mode is not None:
            self.compositing_mode = compositing_mode
        if compositing_quality is not None:
            self.compositing_quality = compositing_quality
        if interpolation_mode is not None:
            self.interpolation_mode = interpolation_mode
        if smoothing_mode is not None:
            self.smoothing_mode = smoothing_mode
        if string_format is not None:
            self.string_format = string_format
        if text_rendering_hint is not None:
            self.text_rendering_hint = text_rendering_hint

    @property
    def compositing_mode(self):
        """Gets the compositing_mode of this GraphicsQualityOptionsData.  # noqa: E501

        Gets or sets the value, that specifies how composited images are drawn to this Graphics.  # noqa: E501

        :return: The compositing_mode of this GraphicsQualityOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._compositing_mode

    @compositing_mode.setter
    def compositing_mode(self, compositing_mode):
        """Sets the compositing_mode of this GraphicsQualityOptionsData.

        Gets or sets the value, that specifies how composited images are drawn to this Graphics.  # noqa: E501

        :param compositing_mode: The compositing_mode of this GraphicsQualityOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["SourceOver", "SourceCopy"]  # noqa: E501
        if not compositing_mode.isdigit():
            if compositing_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `compositing_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(compositing_mode, allowed_values))
            self._compositing_mode = compositing_mode
        else:
            self._compositing_mode = allowed_values[int(compositing_mode) if six.PY3 else long(compositing_mode)]

    @property
    def compositing_quality(self):
        """Gets the compositing_quality of this GraphicsQualityOptionsData.  # noqa: E501

        Gets or sets the rendering quality of composited images drawn to this Graphics.  # noqa: E501

        :return: The compositing_quality of this GraphicsQualityOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._compositing_quality

    @compositing_quality.setter
    def compositing_quality(self, compositing_quality):
        """Sets the compositing_quality of this GraphicsQualityOptionsData.

        Gets or sets the rendering quality of composited images drawn to this Graphics.  # noqa: E501

        :param compositing_quality: The compositing_quality of this GraphicsQualityOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Default", "HighSpeed", "HighQuality", "GammaCorrected", "AssumeLinear", "Invalid"]  # noqa: E501
        if not compositing_quality.isdigit():
            if compositing_quality not in allowed_values:
                raise ValueError(
                    "Invalid value for `compositing_quality` ({0}), must be one of {1}"  # noqa: E501
                    .format(compositing_quality, allowed_values))
            self._compositing_quality = compositing_quality
        else:
            self._compositing_quality = allowed_values[int(compositing_quality) if six.PY3 else long(compositing_quality)]

    @property
    def interpolation_mode(self):
        """Gets the interpolation_mode of this GraphicsQualityOptionsData.  # noqa: E501

        Gets or sets the interpolation mode associated with this Graphics.  # noqa: E501

        :return: The interpolation_mode of this GraphicsQualityOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._interpolation_mode

    @interpolation_mode.setter
    def interpolation_mode(self, interpolation_mode):
        """Sets the interpolation_mode of this GraphicsQualityOptionsData.

        Gets or sets the interpolation mode associated with this Graphics.  # noqa: E501

        :param interpolation_mode: The interpolation_mode of this GraphicsQualityOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Default", "Low", "High", "Bilinear", "Bicubic", "NearestNeighbor", "HighQualityBilinear", "HighQualityBicubic", "Invalid"]  # noqa: E501
        if not interpolation_mode.isdigit():
            if interpolation_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `interpolation_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(interpolation_mode, allowed_values))
            self._interpolation_mode = interpolation_mode
        else:
            self._interpolation_mode = allowed_values[int(interpolation_mode) if six.PY3 else long(interpolation_mode)]

    @property
    def smoothing_mode(self):
        """Gets the smoothing_mode of this GraphicsQualityOptionsData.  # noqa: E501

        Gets or sets the rendering quality for this Graphics.  # noqa: E501

        :return: The smoothing_mode of this GraphicsQualityOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._smoothing_mode

    @smoothing_mode.setter
    def smoothing_mode(self, smoothing_mode):
        """Sets the smoothing_mode of this GraphicsQualityOptionsData.

        Gets or sets the rendering quality for this Graphics.  # noqa: E501

        :param smoothing_mode: The smoothing_mode of this GraphicsQualityOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Default", "HighSpeed", "HighQuality", "None", "AntiAlias", "Invalid"]  # noqa: E501
        if not smoothing_mode.isdigit():
            if smoothing_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `smoothing_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(smoothing_mode, allowed_values))
            self._smoothing_mode = smoothing_mode
        else:
            self._smoothing_mode = allowed_values[int(smoothing_mode) if six.PY3 else long(smoothing_mode)]

    @property
    def string_format(self):
        """Gets the string_format of this GraphicsQualityOptionsData.  # noqa: E501

        Gets or sets text layout information (such as alignment, orientation and tab stops) display manipulations (such as ellipsis insertion and national digit substitution) and OpenType features.  # noqa: E501

        :return: The string_format of this GraphicsQualityOptionsData.  # noqa: E501
        :rtype: StringFormatData
        """
        return self._string_format

    @string_format.setter
    def string_format(self, string_format):
        """Sets the string_format of this GraphicsQualityOptionsData.

        Gets or sets text layout information (such as alignment, orientation and tab stops) display manipulations (such as ellipsis insertion and national digit substitution) and OpenType features.  # noqa: E501

        :param string_format: The string_format of this GraphicsQualityOptionsData.  # noqa: E501
        :type: StringFormatData
        """
        self._string_format = string_format

    @property
    def text_rendering_hint(self):
        """Gets the text_rendering_hint of this GraphicsQualityOptionsData.  # noqa: E501

        Gets or sets the rendering mode for text associated with this Graphics.  # noqa: E501

        :return: The text_rendering_hint of this GraphicsQualityOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._text_rendering_hint

    @text_rendering_hint.setter
    def text_rendering_hint(self, text_rendering_hint):
        """Sets the text_rendering_hint of this GraphicsQualityOptionsData.

        Gets or sets the rendering mode for text associated with this Graphics.  # noqa: E501

        :param text_rendering_hint: The text_rendering_hint of this GraphicsQualityOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["SystemDefault", "SingleBitPerPixelGridFit", "SingleBitPerPixel", "AntiAliasGridFit", "AntiAlias", "ClearTypeGridFit"]  # noqa: E501
        if not text_rendering_hint.isdigit():
            if text_rendering_hint not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_rendering_hint` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_rendering_hint, allowed_values))
            self._text_rendering_hint = text_rendering_hint
        else:
            self._text_rendering_hint = allowed_values[int(text_rendering_hint) if six.PY3 else long(text_rendering_hint)]


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GraphicsQualityOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="preferred_width.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class PreferredWidth(object):
    """DTO container with a preferred width value.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'value': 'float'
    }

    attribute_map = {
        'type': 'Type',
        'value': 'Value'
    }

    def __init__(self, type=None, value=None):  # noqa: E501
        """PreferredWidth - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._value = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if value is not None:
            self.value = value

    @property
    def type(self):
        """Gets the type of this PreferredWidth.  # noqa: E501

        Gets or sets the unit of measure used for this preferred width value.  # noqa: E501

        :return: The type of this PreferredWidth.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PreferredWidth.

        Gets or sets the unit of measure used for this preferred width value.  # noqa: E501

        :param type: The type of this PreferredWidth.  # noqa: E501
        :type: str
        """
        allowed_values = ["Auto", "Percent", "Points"]  # noqa: E501
        if not type.isdigit():
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values))
            self._type = type
        else:
            self._type = allowed_values[int(type) if six.PY3 else long(type)]

    @property
    def value(self):
        """Gets the value of this PreferredWidth.  # noqa: E501

        Gets or sets the preferred width value. The unit of measure is specified in the Type property.  # noqa: E501

        :return: The value of this PreferredWidth.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PreferredWidth.

        Gets or sets the preferred width value. The unit of measure is specified in the Type property.  # noqa: E501

        :param value: The value of this PreferredWidth.  # noqa: E501
        :type: float
        """
        self._value = value


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PreferredWidth):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="execute_mail_merge_request.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import json

from six.moves.urllib.parse import quote
from asposewordscloud import *
from asposewordscloud.models.requests import *
from asposewordscloud.models.responses import *

class ExecuteMailMergeRequest(BaseRequestObject):
    """
    Request model for execute_mail_merge operation.
    Initializes a new instance.
    :param name The filename of the input document.
    :param data Mail merge data.
    :param folder Original document folder.
    :param storage Original document storage.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password for opening an encrypted document.
    :param with_regions The flag indicating whether to execute Mail Merge operation with regions.
    :param mail_merge_data_file The data file.
    :param cleanup The cleanup options.
    :param use_whole_paragraph_as_region The flag indicating whether paragraph with TableStart or TableEnd field should be fully included into mail merge region or particular range between TableStart and TableEnd fields. The default value is true.
    :param dest_file_name The filename of the output document. If this parameter is omitted, the result will be saved with autogenerated name.
    """

    def __init__(self, name, data=None, folder=None, storage=None, load_encoding=None, password=None, with_regions=None, mail_merge_data_file=None, cleanup=None, use_whole_paragraph_as_region=None, dest_file_name=None):
        self.name = name
        self.data = data
        self.folder = folder
        self.storage = storage
        self.load_encoding = load_encoding
        self.password = password
        self.with_regions = with_regions
        self.mail_merge_data_file = mail_merge_data_file
        self.cleanup = cleanup
        self.use_whole_paragraph_as_region = use_whole_paragraph_as_region
        self.dest_file_name = dest_file_name

    def create_http_request(self, api_client):
        # verify the required parameter 'name' is set
        if self.name is None:
            raise ValueError("Missing the required parameter `name` when calling `execute_mail_merge`")  # noqa: E501

        path = '/v4.0/words/{name}/MailMerge'
        path_params = {}
        if self.name is not None:
            path_params['name'] = self.name  # noqa: E501
        else:
            path_params['name'] = ''  # noqa: E501

        # path parameters
        collection_formats = {}
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                path = path.replace(
                    '{%s}' % k,
                    quote(str(v), safe=api_client.configuration.safe_chars_for_path_param)
                )

        # remove optional path parameters
        path = path.replace('//', '/')

        query_params = []
        if self.folder is not None:
                query_params.append(('folder', self.folder))  # noqa: E501
        if self.storage is not None:
                query_params.append(('storage', self.storage))  # noqa: E501
        if self.load_encoding is not None:
                query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
        if self.password is not None:
                query_params.append(('password', self.password))  # noqa: E501
        if self.with_regions is not None:
                query_params.append(('withRegions', self.with_regions))  # noqa: E501
        if self.mail_merge_data_file is not None:
                query_params.append(('mailMergeDataFile', self.mail_merge_data_file))  # noqa: E501
        if self.cleanup is not None:
                query_params.append(('cleanup', self.cleanup))  # noqa: E501
        if self.use_whole_paragraph_as_region is not None:
                query_params.append(('useWholeParagraphAsRegion', self.use_whole_paragraph_as_region))  # noqa: E501
        if self.dest_file_name is not None:
                query_params.append(('destFileName', self.dest_file_name))  # noqa: E501

        header_params = {}
        # HTTP header `Content-Type`
        header_params['Content-Type'] = api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        form_params = []
        if self.data is not None:
            form_params.append(['data', self.data, 'string'])  # noqa: E501

        body_params = None
        return {
            "method": "PUT",
            "path": path,
            "query_params": query_params,
            "header_params": header_params,
            "form_params": form_params,
            "body": body_params,
            "collection_formats": collection_formats,
            "response_type": 'DocumentResponse'  # noqa: E501
        }

    def get_response_type(self):
        return 'DocumentResponse'  # noqa: E501

    def deserialize_response(self, api_client, response):
        return self.deserialize(response, DocumentResponse, api_client)



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="string_format_data.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class StringFormatData(object):
    """Allows to specify System.Drawing.StringFormat options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alignment': 'str',
        'format_flags': 'str',
        'hotkey_prefix': 'str',
        'line_alignment': 'str',
        'trimming': 'str'
    }

    attribute_map = {
        'alignment': 'Alignment',
        'format_flags': 'FormatFlags',
        'hotkey_prefix': 'HotkeyPrefix',
        'line_alignment': 'LineAlignment',
        'trimming': 'Trimming'
    }

    def __init__(self, alignment=None, format_flags=None, hotkey_prefix=None, line_alignment=None, trimming=None):  # noqa: E501
        """StringFormatData - a model defined in Swagger"""  # noqa: E501

        self._alignment = None
        self._format_flags = None
        self._hotkey_prefix = None
        self._line_alignment = None
        self._trimming = None
        self.discriminator = None

        if alignment is not None:
            self.alignment = alignment
        if format_flags is not None:
            self.format_flags = format_flags
        if hotkey_prefix is not None:
            self.hotkey_prefix = hotkey_prefix
        if line_alignment is not None:
            self.line_alignment = line_alignment
        if trimming is not None:
            self.trimming = trimming

    @property
    def alignment(self):
        """Gets the alignment of this StringFormatData.  # noqa: E501

        Gets or sets horizontal alignment of the string.  # noqa: E501

        :return: The alignment of this StringFormatData.  # noqa: E501
        :rtype: str
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """Sets the alignment of this StringFormatData.

        Gets or sets horizontal alignment of the string.  # noqa: E501

        :param alignment: The alignment of this StringFormatData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Near", "Center", "Far"]  # noqa: E501
        if not alignment.isdigit():
            if alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(alignment, allowed_values))
            self._alignment = alignment
        else:
            self._alignment = allowed_values[int(alignment) if six.PY3 else long(alignment)]

    @property
    def format_flags(self):
        """Gets the format_flags of this StringFormatData.  # noqa: E501

        Gets or sets the System.Drawing.StringFormatFlags enumeration, that contains formatting information.  # noqa: E501

        :return: The format_flags of this StringFormatData.  # noqa: E501
        :rtype: str
        """
        return self._format_flags

    @format_flags.setter
    def format_flags(self, format_flags):
        """Sets the format_flags of this StringFormatData.

        Gets or sets the System.Drawing.StringFormatFlags enumeration, that contains formatting information.  # noqa: E501

        :param format_flags: The format_flags of this StringFormatData.  # noqa: E501
        :type: str
        """
        allowed_values = ["DirectionRightToLeft", "DirectionVertical", "FitBlackBox", "DisplayFormatControl", "NoFontFallback", "MeasureTrailingSpaces", "NoWrap", "LineLimit", "NoClip"]  # noqa: E501
        if not format_flags.isdigit():
            if format_flags not in allowed_values:
                raise ValueError(
                    "Invalid value for `format_flags` ({0}), must be one of {1}"  # noqa: E501
                    .format(format_flags, allowed_values))
            self._format_flags = format_flags
        else:
            self._format_flags = allowed_values[int(format_flags) if six.PY3 else long(format_flags)]

    @property
    def hotkey_prefix(self):
        """Gets the hotkey_prefix of this StringFormatData.  # noqa: E501

        Gets or sets the System.Drawing.Text.HotkeyPrefix object for this System.Drawing.StringFormat object.  # noqa: E501

        :return: The hotkey_prefix of this StringFormatData.  # noqa: E501
        :rtype: str
        """
        return self._hotkey_prefix

    @hotkey_prefix.setter
    def hotkey_prefix(self, hotkey_prefix):
        """Sets the hotkey_prefix of this StringFormatData.

        Gets or sets the System.Drawing.Text.HotkeyPrefix object for this System.Drawing.StringFormat object.  # noqa: E501

        :param hotkey_prefix: The hotkey_prefix of this StringFormatData.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Show", "Hide"]  # noqa: E501
        if not hotkey_prefix.isdigit():
            if hotkey_prefix not in allowed_values:
                raise ValueError(
                    "Invalid value for `hotkey_prefix` ({0}), must be one of {1}"  # noqa: E501
                    .format(hotkey_prefix, allowed_values))
            self._hotkey_prefix = hotkey_prefix
        else:
            self._hotkey_prefix = allowed_values[int(hotkey_prefix) if six.PY3 else long(hotkey_prefix)]

    @property
    def line_alignment(self):
        """Gets the line_alignment of this StringFormatData.  # noqa: E501

        Gets or sets the vertical alignment of the string.  # noqa: E501

        :return: The line_alignment of this StringFormatData.  # noqa: E501
        :rtype: str
        """
        return self._line_alignment

    @line_alignment.setter
    def line_alignment(self, line_alignment):
        """Sets the line_alignment of this StringFormatData.

        Gets or sets the vertical alignment of the string.  # noqa: E501

        :param line_alignment: The line_alignment of this StringFormatData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Near", "Center", "Far"]  # noqa: E501
        if not line_alignment.isdigit():
            if line_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `line_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(line_alignment, allowed_values))
            self._line_alignment = line_alignment
        else:
            self._line_alignment = allowed_values[int(line_alignment) if six.PY3 else long(line_alignment)]

    @property
    def trimming(self):
        """Gets the trimming of this StringFormatData.  # noqa: E501

        Gets or sets the System.Drawing.StringTrimming enumeration for this System.Drawing.StringFormat object.  # noqa: E501

        :return: The trimming of this StringFormatData.  # noqa: E501
        :rtype: str
        """
        return self._trimming

    @trimming.setter
    def trimming(self, trimming):
        """Sets the trimming of this StringFormatData.

        Gets or sets the System.Drawing.StringTrimming enumeration for this System.Drawing.StringFormat object.  # noqa: E501

        :param trimming: The trimming of this StringFormatData.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Character", "Word", "EllipsisCharacter", "EllipsisWord", "EllipsisPath"]  # noqa: E501
        if not trimming.isdigit():
            if trimming not in allowed_values:
                raise ValueError(
                    "Invalid value for `trimming` ({0}), must be one of {1}"  # noqa: E501
                    .format(trimming, allowed_values))
            self._trimming = trimming
        else:
            self._trimming = allowed_values[int(trimming) if six.PY3 else long(trimming)]


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StringFormatData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="render_drawing_object_request.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import json

from six.moves.urllib.parse import quote
from asposewordscloud import *
from asposewordscloud.models.requests import *
from asposewordscloud.models.responses import *

class RenderDrawingObjectRequest(BaseRequestObject):
    """
    Request model for render_drawing_object operation.
    Initializes a new instance.
    :param name The filename of the input document.
    :param format The destination format.
    :param index Object index.
    :param node_path The path to the node in the document tree.
    :param folder Original document folder.
    :param storage Original document storage.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password for opening an encrypted document.
    :param dest_file_name Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.
    :param fonts_location Folder in filestorage with custom fonts.
    """

    def __init__(self, name, format, index, node_path=None, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, fonts_location=None):
        self.name = name
        self.format = format
        self.index = index
        self.node_path = node_path
        self.folder = folder
        self.storage = storage
        self.load_encoding = load_encoding
        self.password = password
        self.dest_file_name = dest_file_name
        self.fonts_location = fonts_location

    def create_http_request(self, api_client):
        # verify the required parameter 'name' is set
        if self.name is None:
            raise ValueError("Missing the required parameter `name` when calling `render_drawing_object`")  # noqa: E501
        # verify the required parameter 'format' is set
        if self.format is None:
            raise ValueError("Missing the required parameter `format` when calling `render_drawing_object`")  # noqa: E501
        # verify the required parameter 'index' is set
        if self.index is None:
            raise ValueError("Missing the required parameter `index` when calling `render_drawing_object`")  # noqa: E501

        path = '/v4.0/words/{name}/{nodePath}/drawingObjects/{index}/render'
        path_params = {}
        if self.name is not None:
            path_params['name'] = self.name  # noqa: E501
        else:
            path_params['name'] = ''  # noqa: E501
        if self.index is not None:
            path_params['index'] = self.index  # noqa: E501
        else:
            path_params['index'] = ''  # noqa: E501
        if self.node_path is not None:
            path_params['nodePath'] = self.node_path  # noqa: E501
        else:
            path_params['nodePath'] = ''  # noqa: E501

        # path parameters
        collection_formats = {}
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                path = path.replace(
                    '{%s}' % k,
                    quote(str(v), safe=api_client.configuration.safe_chars_for_path_param)
                )

        # remove optional path parameters
        path = path.replace('//', '/')

        query_params = []
        if self.format is not None:
                query_params.append(('format', self.format))  # noqa: E501
        if self.folder is not None:
                query_params.append(('folder', self.folder))  # noqa: E501
        if self.storage is not None:
                query_params.append(('storage', self.storage))  # noqa: E501
        if self.load_encoding is not None:
                query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
        if self.password is not None:
                query_params.append(('password', self.password))  # noqa: E501
        if self.dest_file_name is not None:
                query_params.append(('destFileName', self.dest_file_name))  # noqa: E501
        if self.fonts_location is not None:
                query_params.append(('fontsLocation', self.fonts_location))  # noqa: E501

        header_params = {}

        form_params = []

        body_params = None
        return {
            "method": "GET",
            "path": path,
            "query_params": query_params,
            "header_params": header_params,
            "form_params": form_params,
            "body": body_params,
            "collection_formats": collection_formats,
            "response_type": 'file'  # noqa: E501
        }

    def get_response_type(self):
        return 'file'  # noqa: E501

    def deserialize_response(self, api_client, response):
        return self.deserialize_file(response.data, response.getheaders(), api_client)
